@@ -1,16 +1,13 @@
-from plover import log
-from plover.log import logging
+from plover.log import logging, LOG_FORMAT
 
 
 class ConsoleNotificationHandler(logging.Handler):
     """ Handler using console to show messages. """
 
-    def __init__(self):
+    def __init__(self, format=LOG_FORMAT):
         super().__init__()
         self.output = None
-        self.setFormatter(
-            log.NoExceptionTracebackFormatter("%(levelname)s: %(message)s")
-        )
+        self.setFormatter(logging.Formatter(format))
 
     def set_output(self, output):
         self.output = output
@@ -24,4 +21,4 @@ class ConsoleNotificationHandler(logging.Handler):
         self.output(message)
 
 
-notification_handler = ConsoleNotificationHandler()
\ No newline at end of file
+notification_handler = ConsoleNotificationHandler()
